# Body

API and shared functionality for all body parts (services) created by Ouroboros
Coding Inc.

This code comes without documentation as it's not meant to be used by anyone
outside of Ouroboros Coding Inc. Please see LICENSE for further information.
